@@ -6,9 +6,12 @@ return (
     'on_top_last'     => 'Text::Editor::Easy',
     'insert_last'     => 'Text::Editor::Easy',
     'change_last'     => 'Text::Editor::Easy',
+	#'on_focus_lost'     => 'Text::Editor::Easy',
 
     # Evnements de zones
     'on_top_editor_change' => 'Text::Editor::Easy::Zone',
+	'on_editor_destroy' => 'Text::Editor::Easy::Zone',
+	'on_new_editor' => 'Text::Editor::Easy::Zone',
 );
 
 =head1 COPYRIGHT & LICENSE
