@@ -9,11 +9,11 @@ Text::Editor::Easy::File_manager - Management of the data that is edited.
 
 =head1 VERSION
 
-Version 0.2
+Version 0.3
 
 =cut
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 =head1 SYNOPSIS
 
@@ -72,6 +72,7 @@ use constant {
     GROWING     => 12,
     TO_DELETE   => 13,
     SAVED_INFO  => 14,
+	UNIQUE_REF => 15,
 
     UNTIL => 0, # Mmorisation de l'appel initial  until (procdure read_until)
                 # On mmorise ici la rfrence  ne pas dpasser
@@ -100,10 +101,12 @@ use constant {
 sub init_file_manager {
 
     #my ( $editor, $file_name, $growing_file, $save_info ) = @_;
-    my ( $file_manager_ref, $reference, $file_name, $growing_file, $save_info )
+    my ( $file_manager_ref, $reference, $unique_ref, $file_name, $growing_file, $save_info )
       = @_;
 
-#print "Dans init_file_manager tid ", threads-> tid, " $file_manager_ref|$reference|$file_name\n";
+    #print "Dans init_file_manager tid ", threads-> tid, " $file_manager_ref|$reference|$unique_ref|$file_name\n";
+
+    $file_manager_ref->[UNIQUE_REF]  = $unique_ref;
 
     my $file_desc;
 
@@ -321,19 +324,6 @@ sub save_line_number {
     return;
 }
 
-sub get_line_number_from_ref_internal {
-    my ( $self, $who, $ref ) = @_;
-
-    $| = 1;
-    my $line_ref = $self->[DESC]{$who}[REF];
-    if (    $line_ref->[LINE_NUMBER]
-        and $self->[LAST_UPDATE] <= $line_ref->[LINE_NUMBER][LAST_COMPUTE] )
-    {
-        return $line_ref->[LINE_NUMBER][NUMBER];
-    }
-    return;
-}
-
 sub prev_line {
     my ( $segment_ref, $pos ) = @_;
 
@@ -682,13 +672,11 @@ sub next_line {
         if ($line_ref) {
             my $ref = save_line( $self, $line_ref );
             print
-              "Dans next_line Une rfrence a t trouve : $line_ref|$ref|",
-              $line_ref->[TEXT], "\n";
+              #"Dans next_line Une rfrence a t trouve : $line_ref|$ref|",$line_ref->[TEXT], "\n";
             return ( $ref, $line_ref->[TEXT] );
         }
         else {    # Aucune ligne  renvoyer
-            print "Dans next line : Pas de rfrence trouve, Threads tid : ",
-              threads->tid, "\n";
+            #print "Dans next line : Pas de rfrence trouve, Threads tid : ", threads->tid, "\n";
             return;
         }
     }
@@ -1135,6 +1123,15 @@ sub load_info {
     return $self->[SAVED_INFO];
 }
 
+sub save_info_on_file {
+    my ( $self, $file ) = @_;
+	
+	print "Dans save_info_on_file : tid ", threads->tid, ", file $file\n";
+	open (INFO, ">$file" ) or die "Impossible d'ouvrir $file : $!\n";
+	print INFO dump $self->[SAVED_INFO];
+	CORE::close INFO;
+}
+
 sub editor_number {
     my ( $self, $number, $options_ref ) = @_;
 	
@@ -1185,7 +1182,6 @@ sub editor_number {
     }
 }
 
-
 sub editor_search {
     my ( $self, $regexp, $options_ref ) = @_;
 	
@@ -1258,8 +1254,81 @@ sub editor_search {
 	return;
 }
 
+sub calc_conf {
+    my ( $self, $options_ref, $sync ) = @_;
+
+	#print "Dans calc_conf : $options_ref->{'cursor_pos'}\n";
+	$options_ref->{'first_line_number'} = get_line_number_from_ref ( $self, $options_ref->{'first_line_ref'} );
+	$options_ref->{'cursor_line_number'} = get_line_number_from_ref ( $self, $options_ref->{'cursor_line_ref'} );
+		
+	# print "Dans calc_conf, aprs calcul :\n\tfirst : $first_line_number\n\tcursor $cursor_line_number\n";
+	# print "\tfirst_line_ord  : ", $options_ref->{'first_line_ord'},"\n";
+	# print "\toffset          : ", $options_ref->{'offset'},"\n";
+	# print "\tcursor_pos      : ", $options_ref->{'cursor_pos'},"\n";
+	# print "\twrap            : ", $options_ref->{'wrap'},"\n";
+
+    my $call_id = Text::Editor::Easy->update_conf( $self->[UNIQUE_REF], $options_ref, $sync );
+	return if ( ! defined $sync or ! defined $call_id );
+    while ( Text::Editor::Easy->async_status($call_id) ne 'ended' ) {
+		# Attente pour synchronisme
+	}
+}
+
+sub get_line_number_from_ref {
+    my ( $self, $ref, $options_ref ) = @_;
+	
+	#print "Dans get_line_number_from_ref, reu : REF $ref\n";
+
+    my $check_every = 20;
+	my $lazy;
+	if ( defined $options_ref and ref $options_ref eq 'HASH' ) {
+        $check_every = $options_ref->{'check_every'} || 20;
+	    $lazy = $options_ref->{'lazy'};
+    }
+
+    my $number = 1;
+	my $indice = 0;
+    my $line_ref = first_ ($self->[ROOT]);
+	while ( defined $line_ref and ( ! defined $line_ref->[REF] or $line_ref->[REF] != $ref ) ) {
+		$number += 1;
+		$indice += 1;
+		$line_ref = next_ ($line_ref);
+		if ( $indice == $check_every ) {
+		    $indice = 0;
+			if ( defined $lazy and Text::Editor::Easy::Comm::anything_for( $lazy ) ) {
+				return;
+		    }
+            if ( Text::Editor::Easy::Comm::anything_for_me() ) {
+				#return if ( Text::Editor::Easy::Comm::have_task_done() );
+				Text::Editor::Easy::Comm::have_task_done()
+		    }
+	    }
+    }
+	return if ( ! defined $line_ref );
+    return $number;
+}
+
+# Tab method => should be defined elsewhere : possible if methods can be added with a sub-object (SAVED_INFO given to the new method
+# and not the complete $self object)
+sub update_tab_config {
+    my ( $self, $name, $options_ref ) = @_;
+	
+	print "Dans update_tab_config : $name|$options_ref\n";
+	my $files_session_ref = $self->[SAVED_INFO]{'file_list'};
+	for my $file_ref ( @{$files_session_ref} ) {
+		if ( $file_ref->{'name'} eq $name ) {
+		    print "Trouv $name dans file_list...|ligne curseur :|", $options_ref->{'cursor_line_number'}, "|\n";
+			print "Ancienne valeur mmorise ... |ligne curseur :|", $file_ref->{'config'}{'cursor_line_number'}, "|\n";
+			$file_ref->{'config'} = $options_ref;
+			return;
+	    }
+    }
+}
+
 =head1 FUNCTIONS
 
+=head2 calc_conf
+
 =head2 clean
 
 =head2 close
@@ -1287,7 +1356,7 @@ Return the line of a Text::Editor::Easy instance and the position (start and end
 
 =head2 first_
 
-=head2 get_line_number_from_ref_internal
+=head2 get_line_number_from_ref
 
 =head2 get_next_ref
 
@@ -1343,12 +1412,16 @@ Return the line of a Text::Editor::Easy instance and the position (start and end
 
 =head2 save_info
 
+=head2 save_info_on_file
+
 =head2 save_internal
 
 =head2 save_line
 
 =head2 save_line_number
 
+=head2 update_tab_config
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008 Sebastien Grommier, all rights reserved.
