@@ -9,11 +9,11 @@ Text::Editor::Easy::Line - Object oriented interface to a file line (managed by
 
 =head1 VERSION
 
-Version 0.2
+Version 0.3
 
 =cut
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 # Les fonctions de File_manager.pm ralisant toutes les mthodes de ce package commencent par "line_" puis reprennent
 # le nom de la mthode
@@ -91,6 +91,14 @@ sub previous {
     );
 }
 
+sub number {
+    my ($self) = @_;
+
+    my $ref           = refaddr $self;
+    my $editor        = $ref_Editor{$ref};
+    return $editor->get_line_number_from_ref( $ref_id{$ref} );
+}
+
 sub seek_start {
     my ($self) = @_;
 
@@ -203,6 +211,10 @@ sub linesize {
 
 =head2 new
 
+=head2 number
+
+Returns the order of the line (that is, it's number).
+
 =head2 next
 
 =head2 previous
