@@ -9,11 +9,11 @@ Text::Editor::Easy::Program::Tab - Tab simulation with just a Text::Editor::Easy
 
 =head1 VERSION
 
-Version 0.2
+Version 0.3
 
 =cut
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 use Text::Editor::Easy::Comm;
 
@@ -26,7 +26,7 @@ my %tab_object;
 
 sub on_main_editor_change {
     my $name = on_top_editor_change(@_);
-    print "On main editor change : $name\n";
+    #print "On main editor change : $name\n";
     $_[0]->change_title($name);
 }
 
@@ -41,6 +41,8 @@ sub on_top_editor_change {
         $tab_editor = bless \do { my $anonymous_scalar }, "Text::Editor::Easy";
         Text::Editor::Easy::Comm::set_ref( $tab_editor, $tab_ref);
         $tab_object{$tab_ref} = $tab_editor;
+		# Il faudrait ajouter une mthode supplmentaire pour le Tab : la mthode qui met  jour save_info (cl "file_list")
+		# ==> cette mthode ne doit pas tre partage par tous les objets Text::Editor::Easy (nouvel objet Tab, hritage  voir)
     }
     my $info_ref      = $tab_editor->load_info;
     my $file_list_ref = $info_ref->{'file_list'};
@@ -49,6 +51,7 @@ sub on_top_editor_change {
 
     # Attention, file_name peut tre indfini, il faut galement tester name...
     my $file_name = $new_on_top_editor->file_name;
+    Text::Editor::Easy::Async->link_editor_to_tab( $new_on_top_editor->get_ref, $tab_ref );
     print "Dans on_top_editor_change aprs appel file_name $file_name\n";
     my $indice = 0;
     my $start  = 0;
@@ -56,7 +59,7 @@ sub on_top_editor_change {
     my $found_ref;
     my $tab_line = "";
   FILE: for my $file_conf_ref ( @{$file_list_ref} ) {
-        $indice += 1;
+        $indice += 1 if ( ! $found_ref );
         my $name = $file_conf_ref->{'name'};
         $end += length($name);
         $tab_line .= $name . ' ';
@@ -72,6 +75,7 @@ sub on_top_editor_change {
     print "Dans on_top_editor_change aprs appel file_name\n";
     if ( !$found_ref ) {
         print "PAs trouv le nom de $file_name\n";
+		$indice += 1;
         my @highlight = ();
         my @file      = ();
         my $name;
@@ -97,14 +101,18 @@ sub on_top_editor_change {
         else {
             $name = 'buffer';
         }
-        push @{$file_list_ref}, { @highlight, @file, 'name' => $name };
+        $hash_ref->{'name'} = $name;
+		#push @{$file_list_ref}, { @highlight, @file, 'name' => $name };
+		push @{$file_list_ref}, $hash_ref;
         $found_ref = [ $start, $end + length($name) ];
         $tab_line .= $name . ' ';
 
         $info_ref->{'file_list'} = $file_list_ref;    # Utile ?
-        $tab_editor->save_info($info_ref);
-    }
 
+    }
+	$info_ref->{'selected'} = $indice - 1;
+    $tab_editor->save_info($info_ref);
+	
     print "Forage de la ligne 1 de tab_editor  $tab_line\n";
     my $first = $tab_editor->first;
     print "On top editor change, premire ligne de l'onglet : |", $first->text,
@@ -119,10 +127,10 @@ sub on_top_editor_change {
         my $text = $first->text;
         if ( $text ne $tab_line ) {
 
-            #$first->set($tab_line);
-            $tab_editor->cursor_set(0);
-            $tab_editor->erase( length($text) );
-            $tab_editor->insert($tab_line);
+            $first->set($tab_line);
+            #$tab_editor->cursor_set(0);
+            #$tab_editor->erase( length($text) );
+            #$tab_editor->insert($tab_line);
         }
     }
     print "On top editor change 2 (", $tab_editor->get_ref,
@@ -179,6 +187,13 @@ sub motion_over_tab {
     }
 
     #print "FILE _ref |$name|$file_ref->{'file'}\n";
+	new_on_top ( $name, $file_ref, 'focus' );
+}
+
+sub new_on_top {
+    my ( $name, $file_ref, $focus ) = @_;
+	
+	#print "Dans new_on_top : $name |", threads->tid, "|\n";
     my $new_on_top = Text::Editor::Easy->whose_name($name);
     if ( !$new_on_top ) {
 
@@ -192,20 +207,87 @@ sub motion_over_tab {
 # Appel asynchrone obligatoire : la cration d'un diteur peut obliger le thread 0  appeler le thread motion
 # de faon synchrone si des vnements sont " rfrencer de faon asynchrone"
 # ==> et en cas d'appel synchrone ici, on aurait un deadlock : 3 en attente de 0, lui-mme en attente de 3
+        #print "Dans motion over tab : un nouvel diteur va tre cr\n";
         Text::Editor::Easy::Async->new($file_ref);
     }
     else {
 
 #$new_on_top->focus;
-        $new_on_top->async->focus;
+        #$new_on_top->async->focus;
+		if ( $focus ) {
+		    $new_on_top->async->focus;
+        }
+		else {
+		    $new_on_top->async->on_top;
+	    }
     }
+}
 
+sub on_editor_destroy {
+    my ( $destroyed_editor, $tab_ref, $hash_ref ) = @_;
+
+    my $destroyed = $hash_ref->{'name'};
+    my $tab_editor = $tab_object{$tab_ref};
+    if ( !$tab_editor ) {
+        print "Cration locale l'diteur correspondant au Tab $tab_ref\n";
+        $tab_editor = bless \do { my $anonymous_scalar }, "Text::Editor::Easy";
+        Text::Editor::Easy::Comm::set_ref( $tab_editor, $tab_ref);
+        $tab_object{$tab_ref} = $tab_editor;
+		# Il faudrait ajouter une mthode supplmentaire pour le Tab : la mthode qui met  jour save_info (cl "file_list")
+		# ==> cette mthode ne doit pas tre partage par tous les objets Text::Editor::Easy (nouvel objet Tab, hritage  voir)
+    }
+    my $info_ref      = $tab_editor->load_info;
+    my $file_list_ref = $info_ref->{'file_list'};
+	my $selected = $info_ref->{'selected'};
+	my $indice = 0;
+	my $found;
+	my $tab_line;
+	my @new_file_list;
+    FILE: for my $file_conf_ref ( @{$file_list_ref} ) {
+		my $name = $file_conf_ref->{'name'};
+        if (  $name eq $destroyed ) {
+		    $found = $indice;
+			next FILE;
+	    }
+		push @new_file_list, $file_conf_ref;
+        $indice += 1;
+        $tab_line .= $name . ' ';
+    }
+	$info_ref->{'file_list'} = \@new_file_list;
+	$tab_editor->save_info($info_ref);
+	$tab_editor->first->set($tab_line);
+	$tab_editor->deselect;
+
+    if ( defined $found and $selected == $found ) {
+	    if ( $found ) {
+		    $indice = $found - 1;
+        }
+	    elsif ( $found <= $indice ) {
+		    $indice = $found;
+        }
+	    else {
+		    return;
+        }
+    }
+	else {
+		if ( defined $found and $found< $selected ) {
+		    $indice = $selected - 1;
+	    }
+		else {
+		    $indice = $selected;
+	    }
+    }
+	new_on_top ( $new_file_list[$indice]->{'name'}, $new_file_list[$indice] );
 }
 
 =head1 FUNCTIONS
 
+=head2 new_on_top
+
 =head2 motion_over_tab
 
+=head2 on_editor_destroy
+
 =head2 on_main_editor_change
 
 =head2 on_top_editor_change
